@@ -12,9 +12,19 @@ if [ ! -e "${CHANGELOG}" ]; then
   exit 1
 fi
 
+if which iconv >/dev/null; then
+ iso2utf() {
+  iconv -f "ISO-8859-15" -t "UTF-8"
+ }
+else
+ iso2utf() {
+  cat
+ }
+fi
+
 make_news() {
   # new changelog entry, without trailing-newlines and with missing LF at EOL
-  sed -e 's| *$||' -e '$a\' "${NEWS}"
+  sed -e 's| *$||' -e '$a\' "${NEWS}" | iso2utf
   # separator
   echo
   echo "==============================================================================="
